
% Module for element mass matrix for reactive term
%
% Output: Selem  ====== 2 x 2 matrix
%
% Selem(1,1), Selem(1,2), Selem(1,3), Selem(2,1), Selem(2.2), Selem(2,3),
%
% Selem(3,1), Selem(3,2), Selem(3,3) to be computed in this routine.
%
% elmat(i,1), elmat(i,2), elmat(i,3) give the index numbers of the vertices of element i
%
% x(elmat(i,j)), y(elmat(i,j)) give the coordinates of the vertices
%
% i = index number of element, imported from AssemblyStepStiffnessMatrix.m
%
% Selem(index1,index2) = (grad phi(elmat(i,index1)),grad phi(i,index2))
%

clear xc
clear yc
clear Selem

for index1 = 1:topology
	xc(index1) = x(elmat(i,index1));
	yc(index1) = y(elmat(i,index1));
end;

Delta = xc(2)*yc(3)-xc(3)*yc(2)+xc(3)*yc(1)-xc(1)*yc(3)+xc(1)*yc(2)-xc(2)*yc(1);

b(1) = (yc(2)-yc(3)) / Delta;  
c(1) = (xc(3)-xc(2)) / Delta;

b(2) = (yc(3)-yc(1)) / Delta;  
c(2) = (xc(1)-xc(3)) / Delta;

b(3) = (yc(1)-yc(2)) / Delta;  
c(3) = (xc(2)-xc(1)) / Delta;

for index1 = 1:topology
	for index2 = 1:topology
		Spuelem(index1,index2) = abs(Delta)/6*b(index2);
		Spvelem(index1,index2) = abs(Delta)/6*c(index2);
		Sppelem(index1,index2) = 0; % adjust this for stabiliser
	end;
end;

for index1 = 1:topology
	for index2 = 1:topology
		Selem(3*index1,3*index2-2)   = Spuelem(index1,index2); 
		Selem(3*index1,3*index2-1)   = Spvelem(index1,index2); 
		Selem(3*index1,3*index2)     = Sppelem(index1,index2); 
	end;
end;

%
% Test problem for evaluation of assembly procedure
%
%for index1 = 1:topology
%	for index2 = 1:topology
%		if index1 == index2
%			Selem(index1,index2) = 1;
%		else
%			Selem(index1,index2) = -1;
%		end;
%	end;
%end;
